@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
-version: 1.4.2
-id: yesod-1.4.2-717f8b22a84feea8286910a26b644b3b
-key: yesod_I0saYPJmNnn9MrQ03Hp9eb
+version: 1.4.3
+id: yesod-1.4.3-08191c485c1368f23c514244ed290a36
+key: yesod_9vcqrSAjXRZGi3ywmihAvJ
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -18,22 +18,22 @@ exposed-modules:
     Yesod Yesod.Default.Config Yesod.Default.Config2 Yesod.Default.Main
     Yesod.Default.Util Yesod.Default.Handlers
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
-library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
-data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-I0saYPJmNnn9MrQ03Hp9eb
+import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
+library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
+data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.3
+hs-libraries: HSyesod-1.4.3-9vcqrSAjXRZGi3ywmihAvJ
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
     blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
+    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
-    fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
-    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-0974645d267a817a7b3484945a31ce66
+    fast-logger-2.4.3-07980efcfdf2821a6e4b588f1620bda1
+    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
+    monad-logger-0.3.18-d371de410ef611b2a9194c84cfcdfbf6
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
@@ -43,15 +43,15 @@ depends:
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
-    wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
-    wai-extra-3.0.15-954ac840c460f6e3c2fb191ca01c5fce
-    wai-logger-2.2.4.1-9478a6051df96b8d5b3214f7fcca2185
-    warp-3.2.3-6de819de378ae4c57281b63b66004254
-    yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
-    yesod-auth-1.4.12-4d106a89bc5f54fb1850e8a22c0b22dc
-    yesod-core-1.4.19-b6ec8d224ea1c49c36126eee73b10ab6
-    yesod-form-1.4.6-6e5c019f77bbb31f3f8cbc24ba3a758a
-    yesod-persistent-1.4.0.3-c6542cb45d0d37a797eae519cf194b16
+    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
+    wai-extra-3.0.15-e42802427c6ef24de665b6ca33fb34be
+    wai-logger-2.2.4.1-b4d6891e20083c91ee31e279044b2010
+    warp-3.2.6-828a707afef115eb99ae18cc2d425cf2
+    yaml-0.8.17-256008eb42bc8c59588e1e26ecb14272
+    yesod-auth-1.4.13.1-06096b715e7e20c2276175f2573f31f6
+    yesod-core-1.4.20.1-8dce2c1559c72b98aae15f98b85f32e0
+    yesod-form-1.4.7-6556fa2dbba4c60b35adfc5077eb6d41
+    yesod-persistent-1.4.0.4-05d2e78a4f4be2f611edc21702f1c928
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
